dpi_util library
Classes
- DpiUtil
- DPI Utility is purely to save me about 5 seconds of typing anytime I have to do display specific dpi percentage non-sense
Extensions
- DpiExtension on BuildContext
- Alternatively use a context extensions to simplify code even further