DpiUtil class
DPI Utility is purely to save me about 5 seconds of typing anytime I have to do display specific dpi percentage non-sense
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getHeight(
BuildContext context) → double - Get Screen Height
-
getPartialHeight(
BuildContext context, {double percentOf = 1}) → double - Get percentage of screen height as DPI
-
getPartialWidth(
BuildContext context, {double percentOf = 1}) → double - Get percentage of screen height as DPI
-
getWidth(
BuildContext context) → double - Get Screen Width